@@ -28,6 +28,7 @@
 import os
 import re
 import errno
+import csv
 import logging as log
 from collections import MutableMapping, OrderedDict
 
@@ -36,6 +37,8 @@ __all__ = [
     'FileConfig',
     'strip_comments',
     'php_inserter',
+    'python_handler',
+    'python_list_handler',
     'parse_block',
     'parse_value'
 ]
@@ -60,7 +63,50 @@ def php_inserter(content, value):
     return content
 
 
-def strip_comments(text):
+def python_handler(varname, default):
+    pattern = r'(?sm)^\s*%s\s*=\s*(.*?)\s*$' % varname
+    reader = lambda match: parse_value(match.group(1))
+    writer = lambda x: '%s = %r' % (varname, str(x) if isinstance(x, unicode)
+                                    else x)
+    return RegexHandler(pattern, writer, reader, default=default)
+
+
+class python_list_handler:
+    def __init__(self, varname, default):
+        self.pattern = re.compile(r'(?m)^\s*%s\s*=\s*\[' % varname)
+        self.varname = varname
+        self.default = default
+
+    def _get_block(self, content):
+        match = self.pattern.search(content)
+        if match:
+            return parse_block(content[match.end():], '[', ']')
+        return None
+
+    def read(self, content):
+        block = self._get_block(content)
+        if block:
+            block = re.sub(r'(?m)\s+', '', block)
+            parts = next(csv.reader([block], skipinitialspace=True), [])
+            return [strip_quotes(x) for x in parts]
+        else:
+            return self.default
+
+    def write(self, content, value):
+        block = self._get_block(content)
+        value = ('%s = [\n' % self.varname +
+                 '\n'.join(['    "%s",' % x for x in value]) +
+                 '\n]')
+        if block:
+            match = self.pattern.search(content)
+            start = content[:match.start()]
+            end = content[match.end() + len(block) + 1:]
+            return start + value + end
+        else:
+            return '%s\n%s' % (content, value)
+
+
+def strip_comments(text, ):
     def replacer(match):
         s = match.group(0)
         if s[0] in ['/', '#']:
@@ -100,6 +146,13 @@ def parse_value(valrepr):
         return float(valrepr)
     except ValueError:
         pass
+    val_lower = valrepr.lower()
+    if val_lower == 'true':
+        return True
+    elif val_lower == 'false':
+        return False
+    elif val_lower in ['none', 'null']:
+        return None
     return strip_quotes(valrepr)
 
 
